@@ -147,11 +147,11 @@ class PersistentIdentifier(db.Model, Timestamp):
                 if object_type and object_uuid:
                     obj.assign(object_type, object_uuid)
                 db.session.add(obj)
-            logger.info(u"Created PID {0}:{1}".format(pid_type, pid_value),
+            logger.info("Created PID {0}:{1}".format(pid_type, pid_value),
                         extra={'pid': obj})
         except IntegrityError:
             logger.exception(
-                u"PID already exists: {0}:{1}".format(pid_type, pid_value),
+                "PID already exists: %s:%s", pid_type, pid_value,
                 extra=dict(
                     pid_type=pid_type,
                     pid_value=pid_value,
@@ -163,7 +163,7 @@ class PersistentIdentifier(db.Model, Timestamp):
             raise PIDAlreadyExists(pid_type=pid_type, pid_value=pid_value)
         except SQLAlchemyError:
             logger.exception(
-                u"Failed to create PID: {0}:{1}".format(pid_type, pid_value),
+                "Failed to create PID: %s:%s", pid_type, pid_value,
                 extra=dict(
                     pid_type=pid_type,
                     pid_value=pid_value,
@@ -281,10 +281,14 @@ class PersistentIdentifier(db.Model, Timestamp):
                 self.object_uuid = object_uuid
                 db.session.add(self)
         except SQLAlchemyError:
-            logger.exception(u"Failed to assign {0}:{1}".format(
-                object_type, object_uuid), extra=dict(pid=self))
+            logger.exception(
+                "Failed to assign %s:%s",
+                object_type,
+                object_uuid,
+                extra=dict(pid=self)
+            )
             raise
-        logger.info(u"Assigned object {0}:{1}".format(
+        logger.info("Assigned object {0}:{1}".format(
             object_type, object_uuid), extra=dict(pid=self))
         return True
 
@@ -311,10 +315,10 @@ class PersistentIdentifier(db.Model, Timestamp):
                 self.object_uuid = None
                 db.session.add(self)
         except SQLAlchemyError:
-            logger.exception(u"Failed to unassign object.".format(self),
+            logger.exception("Failed to unassign object.",
                              extra=dict(pid=self))
             raise
-        logger.info(u"Unassigned object from {0}.".format(self),
+        logger.info("Unassigned object from {0}.".format(self),
                     extra=dict(pid=self))
         return True
 
@@ -360,10 +364,10 @@ class PersistentIdentifier(db.Model, Timestamp):
         except IntegrityError:
             raise PIDDoesNotExistError(pid.pid_type, pid.pid_value)
         except SQLAlchemyError:
-            logger.exception(u"Failed to redirect to {0}".format(
-                pid), extra=dict(pid=self))
+            logger.exception(
+                "Failed to redirect to %s", pid, extra=dict(pid=self))
             raise
-        logger.info(u"Redirected PID to {0}".format(pid), extra=dict(pid=self))
+        logger.info("Redirected PID to {0}".format(pid), extra=dict(pid=self))
         return True
 
     def reserve(self):
@@ -460,11 +464,11 @@ class PersistentIdentifier(db.Model, Timestamp):
                 self.status = status
                 db.session.add(self)
         except SQLAlchemyError:
-            logger.exception(u"Failed to sync status {0}.".format(status),
-                             extra=dict(pid=self))
+            logger.exception(
+                "Failed to sync status %s.", status, extra=dict(pid=self))
             raise
-        logger.info(u"Synced PID status to {0}.".format(status),
-                    extra=dict(pid=self))
+        logger.info(
+            "Synced PID status to {0}.".format(status), extra=dict(pid=self))
         return True
 
     def is_redirected(self):
